# Highlighting the Value of Knative for the C-Suite

**Authors: [Carlos Santana](https://twitter.com/csantanapr) (IBM) and [Omer Bensaadon](https://twitter.com/omer_bensaadon) (VMware)**

**Date: 2021-11-04**

<table style="border: 0;">
<tr style="background-color: var(--md-default-bg-color);">
<td style="border: 0;" width="33%">

<div style="padding:50px;">
<em style="color:#0071c7;font-size: 1em;">"What we are doing with Knative is to provide a developer experience that makes it easier to focus on code. Cloud developers focus on the business problems they are solving without having to coordinate or wait for approvals from platform teams to scale their apps.. Knative is a framework that helps automate platform capabilities so your apps can scale as if they were running on Serverless compute."</em>
<p style="color:#0071c7;font-size: 1em;">-- Aparna Sinha, Director of Product Management, Google</p>
</div>

<div style="padding:50px;">
<em style="color:#0071c7;font-size: 1em;">"The entire idea of cloud native and serverless go together with digital transformation happening at any company. You need to modernize the way you manage apps and develop."</em>
<p style="color:#0071c7;font-size: 1em;">-- Sebastian Goasguen, co-founder of TriggerMesh</p>
</div>

<div style="padding:50px">
<em style="color:#0071c7;font-size: 1em;">"If Kubernetes is an electrical grid, then Knative is its light switch."</em>
<p style="color:#0071c7;font-size: 1em;">-- Kelsey Hightower, Google Cloud Platform</p>
</div>

<div style="padding:50px">
<em style="color:#0071c7;font-size: 1em;">"Designing complex systems that optimize UX, maintainability, and cost is one of the most difficult parts of an engineer's job. Knative's abstractions make it much easier to implement best practices for microservice and serverless architectures, which in turn increases confidence in product changes and decreases defect rates."</em>
<p style="color:#0071c7;font-size: 1em;">-- Noah Fontes, Senior Principal Software Engineer for Relay</p>
</div>

<div style="padding:50px">
<em style="color:#0071c7;font-size: 1em;">"It should be possible for somebody with an algorithm to have it on the platform in an hour."</em>
<p style="color:#0071c7;font-size: 1em;">-- Andrew Webber, Senior Software Engineer of deepc</p>
</div>

<div style="padding:50px">
<em style="color:#0071c7;font-size: 1em;">"You need to be able to choose the right tool at the right level to accelerate your process."</em>
<p style="color:#0071c7;font-size: 1em;">-- Joe Beda, Principal Engineer and cloud native advocate for VMware</p>
</div>

<div style="padding:50px">
<em style="color:#0071c7;font-size: 1em;">"The amount of internal work needed to use Knative is minuscule."</em>
<p style="color:#0071c7;font-size: 1em;">-- Tilen Kavčič, Backend Developer for Outfit7</p>
</div>

<div style="padding:50px">
<em style="color:#0071c7;font-size: 1em;">"I often think of Knative as part of ‘Serverless 2.0.’ It combines the good things about serverless with a loosening of constraints around execution time and availability of resources."</em>
<p style="color:#0071c7;font-size: 1em;">-- Michael Behrendt, Distinguished Engineer and Chief Architect of Serverless and Cloud Functions for IBM</p>
</div>

<div style="padding:50px">
<em style="color:#0071c7;font-size: 1em;">"These open source communities are where enterprises come together to solve complex, heterogenous problem spaces."</em>
<p style="color:#0071c7;font-size: 1em;">-- Clayton Coleman, Hybrid Cloud Architect for Redhat</p>
</div>

</td>

<td style="border: 0;">

<h2 style="font-weight: bold;">Deploy faster and more cost-effectively without hard-to-find, specialized expertise.</h2>

<p>Knative—building on Kubernetes—supports serverless code  development and deployment. This allows your developers to focus on creating code and deploying resilient applications fast without having to become experts on Kubernetes.</p>

<h3 style="font-weight: bold;">What is Knative?</h3>

<p>Knative is an add-on to Kubernetes that helps teams deploy quicker with greater reliability and flexibility. It offers a framework for building a serverless experience for development, testing, and deployment. Developers deploy code faster without worrying about sticky questions of scaling or spending time managing Kubernetes configuration.  Operators get consistent, manageable releases when possible, the flexibility to deploy any image when necessary.</p>

<h3 style="font-weight: bold;">Realize the promise of DevOps.</h3>

<p>For more than ten years, DevOps has been a promise of an effective application development process that deploys faster with less bugs. Offering immense capability but introducing significant complexity, Kubernetes is a key link in realizing value from DevOps. To achieve value at scale, cluster administrators need specialized knowledge, and in the past developers did as well. Knative provides a serverless experience that greatly reduces the need for those who develop and deploy code to have Kubernetes expertise. Operators get consistent, manageable containers when possible and the flexibility to deploy any image when necessary.

<p><i>"What we are doing with Knative is to provide a developer experience that makes it easier to focus on code. Cloud developers focus on the  business problems they are solving without having to coordinate or wait for approvals from platform teams to scale their apps.. Knative is a framework  that helps automate platform capabilities so your apps can scale as if they were running on Serverless compute."</i>
<br>- Aparna Sinha, Director of Product Management, Google

<p><i>“The entire idea of cloud native and serverless go together with digital transformation happening at any company. You need to modernize the way you manage apps and develop.”</i>
<br>- Sebastian Goasguen, co-founder of TriggerMesh, which provides integration-as-code using a Knative platform

<h2 style="font-weight: bold;">A note to the CTO</h2>

<h3 style="font-weight: bold;">What Knative is and how you can use it</h3>

<p><i>"If Kubernetes is an electrical grid, then Knative is its light switch"</i>
<br>- Kelsey Hightower, Google Cloud Platform

<p><h3 style="font-weight: bold;">Knative offers better cost control and better management of complex environments.</h3>

<p>For years, technology teams have worked to break up monolithic codebases into smaller, more manageable sections. Organizations need to be able to develop and innovate faster than the competition, deploying with fewer flaws. Virtualization and API architecture have advanced microservices architecture, but when containers require all the configuration of a bare metal server, the management overhead becomes cost prohibitive.

<p>With Knative Serving, functions or applications can scale up and down to consume only the resources necessary. When not in use, they can scale to zero. Knative massively reduces management requirements and provides easy-to-deploy scaling rules that shut down unused compute resources, saving money and even more time.

<p>Knative can also ease the use of modern test and deployment processes, like green-blue and canary deployments, that stabilize and secure systems.
Knative Eventing expands the possibilities for event-driven architecture. Applications can take action on events across the enterprise through loosely-coupled relationships. Knative conforms to the CloudEvents specifications that allow creating, sending, and interacting with events from any programming language. Solving problems and realizing functionality quickly, applications can be easily created to respond to events in other systems.

<p><i>“Designing complex systems that optimize UX, maintainability, and cost is one of the most difficult parts of an engineer's job. Knative's abstractions make it much easier to implement best practices for microservice and serverless architectures, which in turn increases confidence in product changes and decreases defect rates.”</i>
<br>- Noah Fontes, Senior Principal Software Engineer for Relay, a product of Puppet. Relay is a cloud-native workflow automation platform that extensively leverages Knative.

<h3 style="font-weight: bold;">Enhance productivity for experts outside the IT department.</h3>

<p>Every business unit is now developing code, and developer productivity is key to keeping pace with demand. We need to support the productivity of experts throughout the organization that are now deploying code using Python, Rust, and other development environments in their work as researchers, analysts, and data scientists. Knative accelerates their productivity immensely.

<p><i>“It should be possible for somebody with an algorithm to have it on the platform in an hour.”</i>
<br>- Andrew Webber Senior Software Engineer of deepc, a medtech company that simplifies and improves the workflow in medical imaging diagnostics with pioneering AI and software technologys

<h3 style="font-weight: bold;">Create flexibility when choosing cloud vendors and pursuing future opportunities.</h3>

<p>Knative is designed to be agnostic to the platform, whether a cloud vendor or an on-premises data center. When it comes time to move services to a new platform or infrastructure, there will be less refactoring and re-development.

<p><i>“You need to be able to choose the right tool at the right level to accelerate your process.”</i>
<br>- Joe Beda, Principal Engineer and cloud native advocate for VMware. VMware is a committed sponsor of Knative.

<h3 style="font-weight: bold;">Happier developers don’t spend their lunch hours on job boards.</h3>

<p>Developers like to make things, and with Knative they spend more time doing just that instead of configuring networks and operating systems. They can build and deploy code in a reliable development environment and push to deployment with confidence.

<p><i>“The amount of internal work needed to use Knative is minuscule.”</i>
<br>- Tilen Kavčič, Backend Developer for Outfit7, which uses Knative for key back-end systems

<h3 style="font-weight: bold;">Realizing the value of DevOps in a serverless environment</h3>

<p>Kubernetes enables the spread of containerization throughout the enterprise and enables flexibility through features like scaling. The push for DevOps continues, and Knative is central to progress for many organizations.

<p>The idea of serverless, function-as-a-service architecture has been around for several years, but past iterations locked you into a vendor and were too rigid for the inevitable twenty percent of use cases that are exceptions to any attempt at standardization. Knative allows for simplified deployment of most projects but does not constrain any necessary variations from the norm.

<p><i>“I often think of Knative as part of ‘Serverless 2.0.’ It combines the good things about serverless with a loosening of constraints around execution time and availability of resources.”</i>
<br>- Michael Behrendt, Distinguished Engineer and Chief Architect of Serverless and Cloud Functions for IBM. IBM is a committed sponsor of Knative.

<h3 style="font-weight: bold;">Open source means strong community support and trust.</h3>

<p>Open source has been present in business solutions for several decades, but Kubernetes and now Knative have created a tipping point in that relationship. Both have strong sponsorship by major players such as IBM, Google, Redhat, and VMware. They are among a field of open source projects that have proven themselves reliable, widely accepted, and platform agnostic.

<p>Knative, built to enable serverless workflows on Kubernetes, is already employed for internal solutions, external products, and platform offerings. Anyone utilizing Knative can get involved in the community to get help, contribute, and influence the direction of development.

<p><i>"These open source communities are where enterprises come together to solve complex, heterogenous problem spaces."</i>
<br>- Clayton Coleman, Hybrid Cloud Architect for Redhat

<h2 style="font-weight: bold;">Learn more</h2>

<ul>
<li><b>Conformance</b> Knative is now conformant, meaning that the latest version has validation tools available. It does what it says it can do and it can prove it.
<li><b><a href="https://knative.dev/docs/about/case-studies/deepc/">Case Studies</a></b> Read about organizations using Knative, from platform developers to proven companies to innovative startups.
<li><b><a href="https://knative.dev/docs/getting-started">View the getting started guide</a></b> to get up and running with Knative in an afternoon
<li><b><a href="https://slack.knative.dev">Join the Knative Slack</a></b> to talk to the community.
</ul>

</td>
</tr>
</table>
